IdoFlutter class
Constructors
- IdoFlutter()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addEventHandler(
{required EventHandler initIdoSdkCallBack}) → void -
getGtcId(
) → Future< String?> -
initIdoSdk(
String appId, String channelId) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onBeginEvent(
String key, Map< String, dynamic> ? map) → void -
onBridgeEvent(
String data) → Future< String?> -
onEndEvent(
String key, Map< String, dynamic> ? map) → void -
preInitIdoSdk(
) → void -
registerEventProperties(
Map< String, dynamic> map) → void -
setAppId(
String appId) → void -
setApplicationGroupIdentifier(
String identifier) → void -
setDebugEnable(
bool isDebug) → void -
setEventForceUploadSize(
int size) → void -
setEventUploadInterval(
Long timeMillis) → void -
setInstallChannel(
String channel) → void -
setMaxAppActiveDuration(
Long maxAppActiveDuration) → void -
setMinAppActiveDuration(
Long minAppActiveDuration) → void -
setProfile(
Map< String, dynamic> map) → void -
setProfileForceUploadSize(
int size) → void -
setProfileUploadInterval(
Long timeMillis) → void -
setSessionTimeoutMillis(
Long timeoutMillis) → void -
toString(
) → String -
A string representation of this object.
inherited
-
trackCountEvent(
String eventId, Map< String, dynamic> ? map) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → IdoFlutter
-
no setter
-
platformVersion
→ Future<
String?> -
no setter